Constraints
===========

.. autofunction:: pancad.geometry.constraints.make_constraint

.. autoclass:: pancad.geometry.constraints.AbstractConstraint
    :show-inheritance:
    :members:

.. autoclass:: pancad.geometry.constraints.Angle
    :show-inheritance:
    :members:
    :exclude-members: get_constrained, get_geometry, get_references,

.. autoclass:: pancad.geometry.constraints.Coincident
    :show-inheritance:
    :members:

.. autoclass:: pancad.geometry.constraints.Diameter
    :show-inheritance:
    :members:

.. autoclass:: pancad.geometry.constraints.Distance
    :show-inheritance:
    :members:

.. autoclass:: pancad.geometry.constraints.Equal
    :show-inheritance:
    :members:

.. autoclass:: pancad.geometry.constraints.Horizontal
    :show-inheritance:
    :members:

.. autoclass:: pancad.geometry.constraints.HorizontalDistance
    :show-inheritance:
    :members:

.. autoclass:: pancad.geometry.constraints.Parallel
    :show-inheritance:
    :members:

.. autoclass:: pancad.geometry.constraints.Perpendicular
    :show-inheritance:
    :members:

.. autoclass:: pancad.geometry.constraints.Radius
    :show-inheritance:
    :members:

.. autoclass:: pancad.geometry.constraints.Vertical
    :show-inheritance:
    :members:

.. autoclass:: pancad.geometry.constraints.VerticalDistance
    :show-inheritance:
    :members:

Lower Abstract Constraints
--------------------------

.. autoclass:: pancad.geometry.constraints.distance.AbstractDistance
    :show-inheritance:
    :members:

.. autoclass:: pancad.geometry.constraints.AbstractSnapTo
    :show-inheritance:
    :members:
    :exclude-members: get_constrained, get_geometry, get_references

.. autoclass:: pancad.geometry.constraints.AbstractStateConstraint
    :show-inheritance:
    :members:
    :exclude-members: get_constrained, get_geometry, get_references

.. autoclass:: pancad.geometry.constraints.AbstractValue
    :show-inheritance:
    :members:
    :exclude-members: get_constrained, get_geometry, get_references

.. autoclass:: pancad.geometry.constraints.Abstract1GeometryDistance
    :show-inheritance:
    :members:
    :exclude-members: get_constrained, get_geometry, get_references

.. autoclass:: pancad.geometry.constraints.Abstract2GeometryDistance
    :show-inheritance:
    :members:
    :exclude-members: get_constrained, get_geometry, get_references

.. autoclass:: pancad.geometry.constraints.AbstractDistance2D
    :show-inheritance:
    :members:
    :exclude-members: get_constrained, get_geometry, get_references

